# AKQuant Indicator Reference (All Supported Indicators)

This page is currently maintained in Chinese first.

- Chinese page: [AKQuant 指标全量说明（103 个）](../../zh/guide/rust_indicator_reference.md)
- Related docs:
  - [Capability Boost Plan](../advanced/capability_boost_plan.md)
  - [Indicator Playbook](talib_indicator_playbook.md)
  - [Indicator Scenario Quickref](indicator_scenario_quickref.md)
  - [Chapter 16: AKQuant Indicators in Practice](../textbook/16_rust_indicators.md)
